linked static method

void linked(
  1. ReactiveNode target,
  2. Link link
)

Notifies the debug system that a reactive node was linked to a dependency.

This method should be called when a dependency relationship is established between target and another node via link.

Implementation

@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
static void linked(ReactiveNode target, Link link) {
  getDebug(target)?.call(DebugNodeOperationType.linked, target, link);
  JoltDevTools.handleNodeLifecycle(DebugNodeOperationType.linked, target,
      link: link);
}