run method
Manually runs the watcher function.
This checks the sources and executes the callback if the condition is met.
Example:
watcher.run(); // Manually trigger check
Implementation
@override
void run() {
trigger(sources: null);
}
Manually runs the watcher function.
This checks the sources and executes the callback if the condition is met.
Example:
watcher.run(); // Manually trigger check
@override
void run() {
trigger(sources: null);
}