Until<T> constructor

Until<T>(
  1. ReadableNode<T> source,
  2. bool predicate(
    1. T value
    ), {
  3. bool? detach,
})

Creates an Until that waits for source to satisfy predicate.

The future completes with the value of source when predicate returns true for that value. If the condition is already satisfied at creation time, the future completes immediately.

Parameters:

  • source: The reactive value to observe
  • predicate: Returns true when the condition is met
  • detach: If true, the underlying effect is not bound to the current scope and will not be disposed when the scope is disposed

Implementation

factory Until(ReadableNode<T> source, bool Function(T value) predicate,
    {bool? detach}) = UntilImpl<T>;