isCompleted property

bool get isCompleted

Whether this Until has completed (with a value or error).

True when the condition was satisfied or when the future was completed through some other means. False when still waiting or when cancel was called (the future stays pending in that case).

Implementation

bool get isCompleted;