JoltValueListenable<T> class

A ValueListenable that wraps a Jolt Readable value.

Provides Flutter's ValueListenable interface for Jolt reactive values. Automatically synchronizes with the underlying Jolt value.

Example:

final signal = Signal(42);
final listenable = signal.listenable;
listenable.addListener(() => print('Changed'));
Implemented types
Available extensions

Constructors

JoltValueListenable(Readable<T> node)
Creates a ValueListenable from a Jolt Readable.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
node Readable<T>
The wrapped Jolt Readable value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The current value of the object.
no setteroverride

Methods

addListener(VoidCallback listener) → void
inherited
dispose() → void
Dispose this object and clean up its resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
inherited
removeListener(VoidCallback listener) → void
inherited
toListenableSignal({JoltDebugOption? debug}) ReadonlySignal<T>

Available on ValueListenable<T>, provided by the JoltValueListenableSignalExtension extension

Converts this ValueListenable to a read-only Signal.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited