ValueListenableSignal<T> class

A read-only Signal wrapping a ValueListenable.

Multiple instances share the same DelegatedSignal via reference counting. When all instances are disposed, the shared signal is also disposed.

Inheritance
Available extensions

Constructors

ValueListenableSignal.delegated(DelegatedRefCountHelper<ReadonlySignal<T>> delegated)
Creates from a DelegatedRefCountHelper.

Properties

delegated DelegatedRefCountHelper<ReadonlySignal<T>>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether this node has been disposed.
no setterinherited
listenable JoltValueListenable<T>

Available on Readable<T>, provided by the JoltValueListenableExtension extension

Converts this Jolt value to a Flutter ValueListenable.
no setter
peek → T
Gets the current value without establishing a reactive dependency.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<T>

Available on Readable<T>, provided by the JoltUtilsStreamExtension extension

Converts this reactive value to a broadcast stream.
no setter
value → T
Gets the current value and establishes a reactive dependency.
no setterinherited

Methods

call() → T

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

Gets the current value (callable syntax).
derived<U>(U computed(T value)) Computed<U>

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

Creates a computed value derived from this readable.
dispose() → void
Disposes this node and cleans up resources.
inherited
get() → T

Available on Readable<T>, provided by the JoltUtilsReadableExtension extension

Gets the current value.
listen(void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError, bool immediately = false}) StreamSubscription<T>

Available on Readable<T>, provided by the JoltUtilsStreamExtension extension

Listens to changes in this reactive value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify([bool force = false]) → void
Triggers a change notification without modifying the value.
inherited
toString() String
A string representation of this object.
inherited
until(bool predicate(T value), {bool? detach}) Until<T>

Available on ReadableNode<T>, provided by the JoltUtilsUntilExtension extension

Waits until the value satisfies a condition.
untilChanged({bool? detach}) Until<T>

Available on ReadableNode<T>, provided by the JoltUtilsUntilExtension extension

Waits until the value changes from its current value.
untilWhen<U>(U value, {bool? detach}) Until<T>

Available on ReadableNode<T>, provided by the JoltUtilsUntilExtension extension

Waits until the reactive value equals value.
watch(Widget builder(T value)) Widget

Available on Readable<T>, provided by the JoltFlutterWatchExtension extension

Creates a widget that rebuilds when this value changes.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

from<T>(ValueListenable<T> listenable, {JoltDebugOption? debug}) ReadonlySignal<T>
Creates a ReadonlySignal from a ValueListenable.