ValueNotifierSignal<T> class
A writable Signal wrapping a ValueNotifier with bidirectional sync.
Multiple instances share the same DelegatedSignal via reference counting. When all instances are disposed, the shared signal is also disposed.
- Inheritance
-
- Object
- DelegatedSignal<
T> - ValueNotifierSignal
- Available extensions
Constructors
-
ValueNotifierSignal.delegated(DelegatedRefCountHelper<
Signal< delegated, ValueNotifier<T> >T> notifier) - Creates from a DelegatedRefCountHelper and ValueNotifier.
Properties
-
delegated
→ DelegatedRefCountHelper<
Signal< T> > -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
Whether this node has been disposed.
no setterinherited
-
listenable
→ JoltValueListenable<
T> -
Available on Readable<
Converts this Jolt value to a Flutter ValueListenable.T> , provided by the JoltValueListenableExtension extensionno setter -
notifier
→ ValueNotifier<
T> -
The wrapped ValueNotifier.
final
-
notifier
→ JoltValueNotifier<
T> -
Available on Writable<
Converts this Jolt value to a Flutter ValueNotifier.T> , provided by the JoltValueNotifierExtension extensionno setter - peek → T
-
Gets the current value without establishing a reactive dependency.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
T> -
Available on Readable<
Converts this reactive value to a broadcast stream.T> , provided by the JoltUtilsStreamExtension extensionno setter - value ↔ T
-
Gets the current value and establishes a reactive dependency.
getter/setter pairinherited-getteroverride-setter
Methods
-
call(
) → T -
Available on Readable<
Gets the current value (callable syntax).T> , provided by the JoltUtilsReadableExtension extension -
derived<
U> (U computed(T value)) → Computed< U> -
Available on Readable<
Creates a computed value derived from this readable.T> , provided by the JoltUtilsReadableExtension extension -
dispose(
) → void -
Disposes this node and cleans up resources.
inherited
-
get(
) → T -
Available on Readable<
Gets the current value.T> , provided by the JoltUtilsReadableExtension extension -
listen(
void onData(T event)?, {Function? onError, void onDone()?, bool? cancelOnError, bool immediately = false}) → StreamSubscription< T> -
Available on Readable<
Listens to changes in this reactive value.T> , provided by the JoltUtilsStreamExtension extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
[bool force = false]) → void -
Triggers a change notification without modifying the value.
inherited
-
readonly(
) → ReadonlySignal< T> -
Available on Signal<
Returns a read-only view of this signal.T> , provided by the JoltSignalExtension extension -
set(
T value) → T -
Available on Writable<
Sets the value.T> , provided by the JoltUtilsWritableExtension extension -
toString(
) → String -
A string representation of this object.
inherited
-
until(
bool predicate(T value), {bool? detach}) → Until< T> -
Available on ReadableNode<
Waits until the value satisfies a condition.T> , provided by the JoltUtilsUntilExtension extension -
untilChanged(
{bool? detach}) → Until< T> -
Available on ReadableNode<
Waits until the value changes from its current value.T> , provided by the JoltUtilsUntilExtension extension -
untilWhen<
U> (U value, {bool? detach}) → Until< T> -
Available on ReadableNode<
Waits until the reactive value equalsT> , provided by the JoltUtilsUntilExtension extensionvalue. -
update(
T updater(T value)) → T -
Available on Writable<
Updates the value using an updater function based on the current value.T> , provided by the JoltUtilsWritableExtension extension -
watch(
Widget builder(T value)) → Widget -
Available on Readable<
Creates a widget that rebuilds when this value changes.T> , provided by the JoltFlutterWatchExtension extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
from<
T> (ValueNotifier< T> notifier, {JoltDebugOption? debug}) → Signal<T> - Creates a Signal from a ValueNotifier.