dispose static method
Notifies the debug system that a reactive node was disposed.
This method should be called when a reactive node is being disposed or cleaned up.
Implementation
@pragma("vm:prefer-inline")
@pragma("wasm:prefer-inline")
@pragma("dart2js:prefer-inline")
static void dispose(ReactiveNode target) {
getDebug(target)?.call(DebugNodeOperationType.dispose, target, null);
JoltDevTools.handleNodeLifecycle(DebugNodeOperationType.dispose, target);
}