Until<T> constructor
Until<T> (
- ReadableNode<
T> source, - bool predicate(
- T value
- bool? detach,
Creates an Until that waits for source to satisfy predicate.
The future completes with the value of source when predicate returns
true for that value. If the condition is already satisfied at creation
time, the future completes immediately.
Parameters:
source: The reactive value to observepredicate: Returnstruewhen the condition is metdetach: If true, the underlying effect is not bound to the current scope and will not be disposed when the scope is disposed
Implementation
factory Until(ReadableNode<T> source, bool Function(T value) predicate,
{bool? detach}) = UntilImpl<T>;